redvox.tests.common.test_parallel_utils API documentation

# Module `redvox.tests.common.test_parallel_utils`

Expand source code

    from typing import List
    from unittest import TestCase
    from multiprocessing import Pool

    import redvox.settings as settings
    from redvox.common.parallel_utils import maybe_parallel_map, MappingType

    def map_fn(v: int) -> str:
        return str(v * v)

    class TestParallelUtils(TestCase):
        def setUp(self) -> None:
            self.data: List[int] = list(range(10))
            self.res: List[str] = ["0", "1", "4", "9", "16", "25", "36", "49", "64", "81"]

        def test_normal_provided_pool(self):
            settings.set_parallelism_enabled(True)
            pool = Pool()
            usage_out = []
            res = maybe_parallel_map(pool, map_fn, self.data, usage_out=usage_out)
            self.assertEqual(self.res, list(res))
            self.assertEqual(MappingType.ParallelUnmanaged, usage_out[0])
            pool.close()
            settings.set_parallelism_enabled(False)

        def test_normal_managed_pool(self):
            settings.set_parallelism_enabled(True)
            usage_out = []
            res = maybe_parallel_map(None, map_fn, self.data, usage_out=usage_out)
            self.assertEqual(self.res, list(res))
            self.assertEqual(MappingType.ParallelManaged, usage_out[0])
            settings.set_parallelism_enabled(False)

        def test_normal_serial(self):
            settings.set_parallelism_enabled(False)
            usage_out = []
            res = maybe_parallel_map(None, map_fn, self.data, usage_out=usage_out)
            self.assertEqual(self.res, list(res))
            self.assertEqual(MappingType.Serial, usage_out[0])

        def test_parallel_condition_good(self):
            settings.set_parallelism_enabled(True)
            usage_out = []
            res = maybe_parallel_map(None, map_fn, self.data, usage_out=usage_out, condition=lambda: len(self.data) >= 10)
            self.assertEqual(self.res, list(res))
            self.assertEqual(MappingType.ParallelManaged, usage_out[0])
            settings.set_parallelism_enabled(False)

        def test_parallel_condition_bad(self):
            settings.set_parallelism_enabled(True)
            usage_out = []
            res = maybe_parallel_map(None, map_fn, self.data, usage_out=usage_out, condition=lambda: len(self.data) > 10)
            self.assertEqual(self.res, list(res))
            self.assertEqual(MappingType.Serial, usage_out[0])
            settings.set_parallelism_enabled(False)

## Functions

`def map_fn(v: int) ‑> str`
  Expand source code

      def map_fn(v: int) -> str:
          return str(v * v)

## Classes

`class TestParallelUtils (methodName='runTest')`

  A class whose instances are single test cases.

  By default, the test code itself should be placed in a method named 'runTest'.

  If the fixture may be used for many test cases, create as many test methods as are needed. When instantiating such a TestCase subclass, specify in the constructor arguments the name of the test method that the instance is to execute.

  Test authors should subclass TestCase for their own tests. Construction and deconstruction of the test's environment ('fixture') can be implemented by overriding the 'setUp' and 'tearDown' methods respectively.

  If it is necessary to override the init method, the base class init method must always be called. It is important that subclasses should not change the signature of their init method, since instances of the classes are instantiated automatically by parts of the framework in order to be run.

  When subclassing TestCase, you can set these attributes: * failureException: determines which exception will be raised when the instance's assertion methods fail; test methods raising this exception will be deemed to have 'failed' rather than 'errored'. * longMessage: determines whether long messages (including repr of objects used in assert methods) will be printed on failure in addition to any explicit message passed. * maxDiff: sets the maximum length of a diff in failure messages by assert methods using difflib. It is looked up as an instance attribute so can be configured by individual tests if required.

  Create an instance of the class that will use the named test method when executed. Raises a ValueError if the instance does not have a method with the specified name.

  Expand source code

      class TestParallelUtils(TestCase):
          def setUp(self) -> None:
              self.data: List[int] = list(range(10))
              self.res: List[str] = ["0", "1", "4", "9", "16", "25", "36", "49", "64", "81"]

          def test_normal_provided_pool(self):
              settings.set_parallelism_enabled(True)
              pool = Pool()
              usage_out = []
              res = maybe_parallel_map(pool, map_fn, self.data, usage_out=usage_out)
              self.assertEqual(self.res, list(res))
              self.assertEqual(MappingType.ParallelUnmanaged, usage_out[0])
              pool.close()
              settings.set_parallelism_enabled(False)

          def test_normal_managed_pool(self):
              settings.set_parallelism_enabled(True)
              usage_out = []
              res = maybe_parallel_map(None, map_fn, self.data, usage_out=usage_out)
              self.assertEqual(self.res, list(res))
              self.assertEqual(MappingType.ParallelManaged, usage_out[0])
              settings.set_parallelism_enabled(False)

          def test_normal_serial(self):
              settings.set_parallelism_enabled(False)
              usage_out = []
              res = maybe_parallel_map(None, map_fn, self.data, usage_out=usage_out)
              self.assertEqual(self.res, list(res))
              self.assertEqual(MappingType.Serial, usage_out[0])

          def test_parallel_condition_good(self):
              settings.set_parallelism_enabled(True)
              usage_out = []
              res = maybe_parallel_map(None, map_fn, self.data, usage_out=usage_out, condition=lambda: len(self.data) >= 10)
              self.assertEqual(self.res, list(res))
              self.assertEqual(MappingType.ParallelManaged, usage_out[0])
              settings.set_parallelism_enabled(False)

          def test_parallel_condition_bad(self):
              settings.set_parallelism_enabled(True)
              usage_out = []
              res = maybe_parallel_map(None, map_fn, self.data, usage_out=usage_out, condition=lambda: len(self.data) > 10)
              self.assertEqual(self.res, list(res))
              self.assertEqual(MappingType.Serial, usage_out[0])
              settings.set_parallelism_enabled(False)

  ### Ancestors

  - unittest.case.TestCase

  ### Methods

  `def setUp(self) ‑> None`

    Hook method for setting up the test fixture before exercising it.

    Expand source code

        def setUp(self) -> None:
            self.data: List[int] = list(range(10))
            self.res: List[str] = ["0", "1", "4", "9", "16", "25", "36", "49", "64", "81"]

  `def test_normal_managed_pool(self)`
    Expand source code

        def test_normal_managed_pool(self):
            settings.set_parallelism_enabled(True)
            usage_out = []
            res = maybe_parallel_map(None, map_fn, self.data, usage_out=usage_out)
            self.assertEqual(self.res, list(res))
            self.assertEqual(MappingType.ParallelManaged, usage_out[0])
            settings.set_parallelism_enabled(False)

  `def test_normal_provided_pool(self)`
    Expand source code

        def test_normal_provided_pool(self):
            settings.set_parallelism_enabled(True)
            pool = Pool()
            usage_out = []
            res = maybe_parallel_map(pool, map_fn, self.data, usage_out=usage_out)
            self.assertEqual(self.res, list(res))
            self.assertEqual(MappingType.ParallelUnmanaged, usage_out[0])
            pool.close()
            settings.set_parallelism_enabled(False)

  `def test_normal_serial(self)`
    Expand source code

        def test_normal_serial(self):
            settings.set_parallelism_enabled(False)
            usage_out = []
            res = maybe_parallel_map(None, map_fn, self.data, usage_out=usage_out)
            self.assertEqual(self.res, list(res))
            self.assertEqual(MappingType.Serial, usage_out[0])

  `def test_parallel_condition_bad(self)`
    Expand source code

        def test_parallel_condition_bad(self):
            settings.set_parallelism_enabled(True)
            usage_out = []
            res = maybe_parallel_map(None, map_fn, self.data, usage_out=usage_out, condition=lambda: len(self.data) > 10)
            self.assertEqual(self.res, list(res))
            self.assertEqual(MappingType.Serial, usage_out[0])
            settings.set_parallelism_enabled(False)

  `def test_parallel_condition_good(self)`
    Expand source code

        def test_parallel_condition_good(self):
            settings.set_parallelism_enabled(True)
            usage_out = []
            res = maybe_parallel_map(None, map_fn, self.data, usage_out=usage_out, condition=lambda: len(self.data) >= 10)
            self.assertEqual(self.res, list(res))
            self.assertEqual(MappingType.ParallelManaged, usage_out[0])
            settings.set_parallelism_enabled(False)